==> giada_0.16.2.2+ds1.orig.tar.xz: giada-0.16.2.2/src/gui/elems/mainWindow/keyboard/sampleChannelButton.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */


#ifndef GE_SAMPLE_CHANNEL_BUTTON_H
#define GE_SAMPLE_CHANNEL_BUTTON_H


#include "channelButton.h"


namespace giada {
namespace m 
{ 
class SampleChannel; 
}
namespace v
{
class geSampleChannelButton : public geChannelButton
{
public:

	geSampleChannelButton(int x, int y, int w, int h, ID channelId);
	
    int handle(int e) override;

    void refresh() override;
};
}} // giada::v::


#endif

==> giada_0.20.0+ds1.orig.tar.xz: giada-0.20.0/src/gui/elems/mainWindow/keyboard/sampleChannelButton.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */

#ifndef GE_SAMPLE_CHANNEL_BUTTON_H
#define GE_SAMPLE_CHANNEL_BUTTON_H

#include "channelButton.h"

namespace giada
{
namespace v
{
class geSampleChannelButton : public geChannelButton
{
public:
	geSampleChannelButton(int x, int y, int w, int h, const c::channel::Data& d);

	int handle(int e) override;

	void refresh() override;
};
} // namespace v
} // namespace giada

#endif
